@@ -29,6 +29,22 @@ INSERT_COLUMNS_SEP = ',\n   '
 INSERT_VALUES_SEP = ',\n          '
 
 
+class NormAsIs:
+    def __init__(self, value):
+        self.value = value
+
+    def __repr__(self):
+        return f'AsIs({repr(self.value)})'
+
+    def __eq__(self, o):
+        try:
+            if o.value == self.value:
+                return True
+            return False
+        except AttributeError:
+            return False
+
+
 class BogusQuery(Exception):
     pass
 
@@ -266,9 +282,10 @@ class SELECT(_SELECT_UPDATE):
             s.chain.append((HAVING, arg))
         return s
 
-    def ORDER_BY(self, stmt):
+    def ORDER_BY(self, *args):
         s = self.child()
-        s.chain.append((ORDER_BY, stmt))
+        for arg in args:
+            s.chain.append((ORDER_BY, arg))
         return s
 
     def GROUP_BY(self, *args):
@@ -377,7 +394,8 @@ class INSERT(object):
                 key = f'{col_name}_{index}'
 
                 if col_name in d:
-                    binds[key] = d[col_name]
+                    if not self._is_asis(d[col_name]):
+                        binds[key] = d[col_name]
                 else:
                     binds[key] = self.default
 
@@ -395,12 +413,12 @@ class INSERT(object):
             if self.data is None:
                 return None
             if not self.multi_data:
-                return sorted([key for key in self.data])
+                return list(sorted([key for key in self.data]))
             else:
                 columns = set()
                 for d in self.data:
                     columns |= set(d)
-                self._columns = sorted(columns)
+                self._columns = list(sorted(columns))
         return self._columns
 
     @property
@@ -410,10 +428,16 @@ class INSERT(object):
         else:
             return self._query([self.data])
 
+    def _bind_param_name(self, col_name, index):
+        return f'{self.bind_prefix}{col_name}_{index}{self.bind_postfix}'
+
+    def _is_asis(self, val):
+        if isinstance(val, NormAsIs):
+            return True
+        return False
+
     def _query(self, data):
         q = 'INSERT INTO %s ' % self.table
-        pref = self.bind_prefix
-        post = self.bind_postfix
 
         if self.columns:
             q += '('
@@ -433,10 +457,12 @@ class INSERT(object):
                 q += '('
                 last_col_ix = len(self.columns) - 1
                 for ix, col_name in enumerate(self.columns):
-                    if last_col_ix != ix:
-                        q += f'{pref}{col_name}_{index}{post}, '
+                    if self._is_asis(d.get(col_name)):
+                        q += d.get(col_name).value
                     else:
-                        q += f'{pref}{col_name}_{index}{post}'
+                        q += self._bind_param_name(col_name, index)
+                    if last_col_ix != ix:
+                        q += ', '
 
                 q += ')'
         if self.on_conflict:
